#
# Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
#
# You should have find a copy of NFSChina License. If not, please contact us
# by email <os_support@nfschina.com>
#

class AIAbilityManager:
    """
    AI能力管理类，用于管理AI能力与大模型的对应关系
    """
    def __init__(self):
        self.ability_model_mapping = {}
        

    def register_ability_model(self, ability_name, model_name):
        """
        注册AI能力和模型对应关系

        :param ability_name: AI能力的名称，例如 "chat_text"
        :param model_name: AI大模型
        """
        if ability_name not in self.ability_model_mapping:
            self.ability_model_mapping[ability_name] = []
        self.ability_model_mapping[ability_name].append(model_name)
        
    def unregister_ability_model(self, ability_name, model_name):
        """
        去注册AI能力和模型对应关系

        :param ability_name: AI能力的名称，例如 "chat_text"
        :param model_instance: AI大模型
        """
        if ability_name not in self.ability_model_mapping or model_name not in self.ability_model_mapping[ability_name]:
            return
        self.ability_model_mapping[ability_name].remove(model_name)

    def get_model_for_ability(self, ability_name):
        """
        获取与指定AI能力对应的大模型
        当前仅先返回第一个可用大模型实例，后续需要根据模型优先级、资源情况进行考虑度量，择优选择可用模型

        :param ability_name: AI能力的名称
        :return: 与该能力对应的大模型列表，如果能力未注册则返回[]
        """
        if ability_name in self.ability_model_mapping and  self.ability_model_mapping[ability_name]:
            return self.ability_model_mapping[ability_name]
        else:
            return []
