#
# Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
#
# You should have find a copy of NFSChina License. If not, please contact us
# by email <os_support@nfschina.com>
#

import os
from http import HTTPStatus
import dashscope
from dashscope import MultiModalConversation
#from .model_base import AIModelBase
from libfoundai.model_adapter.model_base import AIModelBase
    
class Bailian(AIModelBase):
    def __init__(self, models):
        """
        百炼模型类的构造函数
        models: {model_name:"bailian", key:"xxxxxxxx"}
        :param key: API密钥（实际从百炼平台获取）
        """
        super().__init__()
        #print(f"Bailian: {models}")
        if not models.get("key"):
            raise ValueError(f"No key")
        self.api_key = models["key"]
        self.interface_registry['chat_text'] = self.chat_text
        self.interface_registry['get_content_ocr'] = self.get_content_ocr


    def chat_text(self, prompt):
        messages = [{'role': 'system', 'content': 'You are a helpful assistant.'},{'role': 'user', 'content': prompt}]
        response = None
        try:
            response = dashscope.Generation.call(
                api_key=self.api_key,
                model="qwen-plus",
                messages=messages,
                result_format="message"
            )
        except Exception as e:
            #print(f"generate_response exception :{e}")
            return False, "generate_response exception"

        if response.status_code == HTTPStatus.OK:
            #print(response)
            return True, response.output.choices[0].message.content
        else:
            errmsg = f"Err: 错误码：{response.code}, 错误信息: {response.message}"
            #print(errmsg)
            return False, errmsg


    def get_content_ocr(self, image_path):
        file_path = f"file://{image_path}"
        response = None
        messages = [{'role':'user',
                    'content': [{'image': file_path,
                                "min_pixels": 28 * 28 * 4,
                                "max_pixels": 28 * 28 * 1280
                                },
                         # 为保证识别效果，目前模型内部会统一使用"Read all the text in the image."进行识别，用户输入的文本不会生效。
                        {'text': 'Read all the text in the image.'}]}]
        try:
            response = MultiModalConversation.call(
                api_key=self.api_key,
                model='qwen-vl-ocr',
                messages=messages)
        
        except Exception as e:
            #print(f"generate_response exception :{e}")
            return False, "generate_response exception"

        if response.status_code == HTTPStatus.OK:
            rsp_msg = response["output"]["choices"][0]["message"].content[0]["text"]
            #print(rsp_msg)
            return True, rsp_msg
        else:
            errmsg = f"Err: 错误码：{response.code}, 错误信息: {response.message}"
            #print(errmsg)
            return False, errmsg
