#
# Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
#
# You should have find a copy of NFSChina License. If not, please contact us
# by email <os_support@nfschina.com>
#

import subprocess
import os
from libfoundai.model_adapter.model_base import AIModelBase

class LocalOcr(AIModelBase):
    def __init__(self, models):
        super().__init__()
        # 检查 tesseract 是否安装
        self.tesseract_path = self._find_tesseract()
        if not self.tesseract_path:
            raise RuntimeError("tesseract is not installed or not in the PATH.")
        
        # 检查是否支持 chi_sim
        if not self._check_language_support('chi_sim'):
            raise RuntimeError("tesseract does not support chi_sim language.")
        self.interface_registry['get_content_ocr'] = self.get_content_ocr

    def _find_tesseract(self):
        for path in os.environ["PATH"].split(os.pathsep):
            path = path.strip('"')
            executable = os.path.join(path, "tesseract")
            if os.path.isfile(executable) and os.access(executable, os.X_OK):
                return executable
        return None

    def _check_language_support(self, lang):
        try:
            result = subprocess.run([self.tesseract_path, "--list-langs"], capture_output=True, text=True)
            return lang in result.stdout
        except subprocess.CalledProcessError as e:
            #print("Error checking language support:", e)
            return False

    def get_content_ocr(self, image_path):
        try:
            # 执行 tesseract 命令
            cmd = [self.tesseract_path, image_path, "stdout", "-l", "chi_sim"]
            result = subprocess.run(cmd, capture_output=True, text=True)
            if result.returncode != 0:
                return False, f"tesseract ocr fail : {result.stderr}"
            return True, result.stdout
        except Exception as e:
            return False, f"tesseract ocr fail : {e}"

