#
# Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
#
# You should have find a copy of NFSChina License. If not, please contact us
# by email <os_support@nfschina.com>
#

#模型基类
class AIModelBase:
    """
    AI模型的基类，定义了接口注册的通用机制
    """
    def __init__(self):
        # 用于存储每个实例自己的接口注册信息的字典，在子类中会被具体使用
        self.interface_registry = {}

    def call_interface(self, name, *args, **kwargs):
        if name in self.interface_registry:
            func = self.interface_registry[name]
            return func(*args, **kwargs)  # 正确的调用，不需要再次传递self
        else:
            raise ValueError(f"No interface found with name '{name}'")
    
    