#
# Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
#
# You should have find a copy of NFSChina License. If not, please contact us
# by email <os_support@nfschina.com>
#

from  libfoundai.utils.ai_framwork_config import Config
import importlib

def get_class_by_name(module_name, class_name, param):
    module = importlib.import_module(module_name)
    return getattr(module, class_name)(param)

# AI模型工厂类，用于管理模型名称和模型类的映射以及实例化
class AIModelFactory:
    def __init__(self):
        self.model_mapping = {}

    '''
    def access_model(self, name, model_class):
        """
        注册AI模型类到工厂的映射关系中

        :param name: 模型对应的名称（字符串）
        :param model_class: 具体的AI模型类对象
        """
        #print(f"name:{name}, model_class:{model_class}")
        self.model_mapping[name] = model_class

    '''

    def create_instance(self, models):
        """
        根据给定的名称创建对应的AI模型类实例，并传递相应参数

        :param name: 要创建实例的模型对应的名称（字符串）
        :param args: 位置参数，传递给模型类构造函数
        :param kwargs: 关键字参数，传递给模型类构造函数
        :return: 实例化后的模型对象，如果名称不存在对应的类则返回 None
        """
        model_name = models["name"]
        module_name = models["module_name"]
        class_name = models["class_name"]

        try:
            model_instance = get_class_by_name(module_name,class_name,models)
            if model_instance:
                return model_instance, f"create {model_name} instance success"
            else:
                return None, f"create {model_name} instance fail"
            
        except Exception as e:
            return False, f"create_instance exception :{e}"




class AIModelsManager:
    def __init__(self):
        self.available_model = []
        self.models_instance_map = {}
        self.model_factory = None
        self.registered_models = {}
        self.init_models()

    def init_models(self):
        self.model_factory = AIModelFactory()
        #根据模型配置，动态导入对应模型
        self.registered_models = Config.get_models()
        if self.registered_models:
            for model in self.registered_models:
                #print(f"model:{model}")
                #self.model_factory.access_model(model, get_class_by_name(module_name, class_name))
                self.req_model(self.registered_models[model])

        #print(f"models_instance_map: {self.models_instance_map}")
        

    #模型注册
    def req_model(self, models):
        if "name" not in models or "key" not in models:
            return False, f"param must include model_name and key"
        model_name = models.get("name")
        #print(f"AIModelsManager:the param: {models}")

        try:
            model_instance, msg = self.model_factory.create_instance(models)
            #print(f"create_instance: {msg}")
            if model_instance != None:
                self.models_instance_map[model_name] = model_instance
                self.available_model.append(model_name)
                return True, "req_model success"
            else:
                err_msg = msg
                #print(err_msg)
                return False, err_msg
        except Exception as e:
            return False, f"req_model exception :{e}"

    def get_available_model(self, model_name):
        """
        获取指定模型的可用的实例

        :param model_name: 模型名称
        :return: 与该能力对应的大模型实例列表，如果能力未注册则返回空列表
        """
        return self.models_instance_map.get(model_name, None)
