#
# Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
#
# You should have find a copy of NFSChina License. If not, please contact us
# by email <os_support@nfschina.com>
#

import json

CONFIG_PATH="/etc/libfoundai/foundai.json"

class Config:
    @staticmethod
    def read_json():
        """
        静态方法，读取 JSON 文件并将其内容作为 Python 对象返回
        :return: 从文件中读取的 Python 对象，如果文件不存在或读取错误则返回 None
        """
        try:
            with open(CONFIG_PATH, 'r') as json_file:
                data = json.load(json_file)
            return data
        except FileNotFoundError:
            print(f"文件 {CONFIG_PATH} 不存在")
        except json.JSONDecodeError:
            print(f"文件 {CONFIG_PATH} 包含无效的 JSON 数据")
        except Exception as e:
            print(f"读取文件 {CONFIG_PATH} 时出现错误: {e}")
        return None

    @staticmethod
    def write_json(data):
        """
        静态方法，将 Python 对象作为 JSON 数据写入文件
        :param data: 要写入的 Python 对象，例如字典、列表等
        """
        try:
            with open(CONFIG_PATH, 'w') as json_file:
                json.dump(data, json_file, indent=4)
            print(f"数据已成功写入到 {CONFIG_PATH}")
        except Exception as e:
            print(f"写入文件 {CONFIG_PATH} 时出现错误: {e}")

    @staticmethod
    def modify_ability_match_model(new_ability_match_model):
        """
        静态方法，修改 ability_match_model 部分的内容
        :param new_ability_match_model: 新的 ability_match_model 内容，将替换原有的内容
        """
        data = Config.read_json()
        if data:
            data["ability_match_model"] = new_ability_match_model
            Config.write_json(data)

    @staticmethod
    def modify_models(new_models):
        """
        静态方法，修改 models 部分的内容
        :param new_models: 新的 models 部分的新内容，将替换原有的内容
        """
        data = Config.read_json()
        if data:
            data["models"] = new_models
            Config.write_json(data)

    @staticmethod
    def get_ability_match_model():
        """
        静态方法，读取 ability_match_model 部分的内容
        :return: ability_match_model 部分的内容，如果文件不存在或读取错误则返回 None
        """
        data = Config.read_json()
        if data:
            return data.get("ability_match_model")
        return None

    @staticmethod
    def get_models():
        """
        静态方法，读取 models 部分的内容
        :return: models 部分的内容，如果文件不存在或读取错误则返回 None
        """
        data = Config.read_json()
        if data:
            return data.get("models")
        return None



